env

package
v0.0.0-...-4b21e95 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 30, 2022 License: AGPL-3.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetBytesEnv

func GetBytesEnv(name string, varName string) (datasize.ByteSize, error)

GetBytesEnv gets a datasize.ByteSize value from the environment and parses it

func GetDurationEnv

func GetDurationEnv(name string, varName string) (time.Duration, error)

GetDurationEnv gets a duration value from the environment and parses it

func GetEnv

func GetEnv(name string, varName string) (string, error)

GetEnv gets a string value from the environment and parses it

func GetIntEnv

func GetIntEnv(name string, varName string) (int, error)

GetIntEnv gets an integer value from the environment and parses it

Types

This section is empty.

Jump to